@@ -319,11 +319,11 @@ BackendLLVM::addCUDAGlobalVariable(const std::string& name, int size,
 
     llvm::Constant* constant = nullptr;
 
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         constant = ll.constant(*(const float*)init_data);
-    } else if (type == TypeDesc::TypeInt) {
+    } else if (type == TypeInt) {
         constant = ll.constant(*(const int*)init_data);
-    } else if (type == TypeDesc::TypeString) {
+    } else if (type == TypeString) {
         constant = ll.constant64(((const ustring*)init_data)->hash());
         // N.B. Since this is the OptiX side specifically, we will represent
         // strings as the ustringhash, so we know it as a constant.
@@ -456,13 +456,13 @@ BackendLLVM::llvm_load_value(const Symbol& sym, int deriv,
     if (sym.is_constant() && !sym.typespec().is_array() && !arrayindex) {
         // Shortcut for simple constants
         if (sym.typespec().is_float()) {
-            if (cast == TypeDesc::TypeInt)
+            if (cast == TypeInt)
                 return ll.constant((int)sym.get_float());
             else
                 return ll.constant(sym.get_float());
         }
         if (sym.typespec().is_int()) {
-            if (cast == TypeDesc::TypeFloat)
+            if (cast == TypeFloat)
                 return ll.constant((float)sym.get_int());
             else
                 return ll.constant(sym.get_int());
@@ -516,9 +516,9 @@ BackendLLVM::llvm_load_value(llvm::Value* ptr, const TypeSpec& type, int deriv,
         return result;
 
     // Handle int<->float type casting
-    if (type.is_float_based() && !type.is_array() && cast == TypeDesc::TypeInt)
+    if (type.is_float_based() && !type.is_array() && cast == TypeInt)
         result = ll.op_float_to_int(result);
-    else if (type.is_int() && cast == TypeDesc::TypeFloat)
+    else if (type.is_int() && cast == TypeFloat)
         result = ll.op_int_to_float(result);
     else if (type.is_string() && cast == TypeDesc::LONGLONG) {
         result = ll.ptr_to_cast(result, ll.type_longlong());
@@ -552,13 +552,13 @@ BackendLLVM::llvm_load_constant_value(const Symbol& sym, int arrayindex,
                 && "Called llvm_load_constant_value with negative array index");
 
     if (sym.typespec().is_float()) {
-        if (cast == TypeDesc::TypeInt)
+        if (cast == TypeInt)
             return ll.constant((int)sym.get_float(arrayindex));
         else
             return ll.constant(sym.get_float(arrayindex));
     }
     if (sym.typespec().is_int()) {
-        if (cast == TypeDesc::TypeFloat)
+        if (cast == TypeFloat)
             return ll.constant((float)sym.get_int(arrayindex));
         else
             return ll.constant(sym.get_int(arrayindex));
@@ -802,7 +802,7 @@ BackendLLVM::llvm_test_nonzero(Symbol& val, bool test_derivs)
     TypeDesc t = ts.simpletype();
 
     // Handle int case -- guaranteed no derivs, no multi-component
-    if (t == TypeDesc::TypeInt)
+    if (t == TypeInt)
         return ll.op_ne(llvm_load_value(val), ll.constant(0));
 
     // float-based
