@@ -470,14 +470,12 @@ SimpleRenderer::get_array_attribute(ShaderGlobals* sg, bool derivatives,
 
     // In order to test getattribute(), respond positively to
     // "options"/"blahblah"
-    if (object == "options" && name == "blahblah"
-        && type == TypeDesc::TypeFloat) {
+    if (object == "options" && name == "blahblah" && type == TypeFloat) {
         *(float*)val = 3.14159;
         return true;
     }
 
-    if (object.empty() && name == "shading:index"
-        && type == TypeDesc::TypeInt) {
+    if (object.empty() && name == "shading:index" && type == TypeInt) {
         *(int*)val = OSL::get_shade_index(sg);
         return true;
     }
@@ -511,7 +509,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
     // look up something specific to the primitive, rather than have hard-
     // coded names.
 
-    if (name == u_s && type == TypeDesc::TypeFloat) {
+    if (name == u_s && type == TypeFloat) {
         ((float*)val)[0] = sg->u;
         if (derivatives) {
             ((float*)val)[1] = sg->dudx;
@@ -519,7 +517,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_t && type == TypeDesc::TypeFloat) {
+    if (name == u_t && type == TypeFloat) {
         ((float*)val)[0] = sg->v;
         if (derivatives) {
             ((float*)val)[1] = sg->dvdx;
@@ -527,7 +525,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_red && type == TypeDesc::TypeFloat && sg->P.x > 0.5f) {
+    if (name == u_red && type == TypeFloat && sg->P.x > 0.5f) {
         ((float*)val)[0] = sg->u;
         if (derivatives) {
             ((float*)val)[1] = sg->dudx;
@@ -535,7 +533,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_green && type == TypeDesc::TypeFloat && sg->P.x < 0.5f) {
+    if (name == u_green && type == TypeFloat && sg->P.x < 0.5f) {
         ((float*)val)[0] = sg->v;
         if (derivatives) {
             ((float*)val)[1] = sg->dvdx;
@@ -543,7 +541,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_blue && type == TypeDesc::TypeFloat
+    if (name == u_blue && type == TypeFloat
         && ((static_cast<int>(sg->P.y * 12) % 2) == 0)) {
         ((float*)val)[0] = 1.0f - sg->u;
         if (derivatives) {
@@ -743,7 +741,7 @@ SimpleRenderer::get_osl_version(ShaderGlobals* /*sg*/, bool /*derivs*/,
                                 ustringhash /*object*/, TypeDesc type,
                                 ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeInt) {
+    if (type == TypeInt) {
         ((int*)val)[0] = OSL_VERSION;
         return true;
     }
@@ -770,7 +768,7 @@ SimpleRenderer::get_camera_projection(ShaderGlobals* /*sg*/, bool /*derivs*/,
                                       ustringhash /*object*/, TypeDesc type,
                                       ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeString) {
+    if (type == TypeString) {
         ((ustring*)val)[0] = m_projection;
         return true;
     }
@@ -784,7 +782,7 @@ SimpleRenderer::get_camera_fov(ShaderGlobals* /*sg*/, bool derivs,
                                ustringhash /*name*/, void* val)
 {
     // N.B. in a real renderer, this may be time-dependent
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_fov;
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
@@ -799,7 +797,7 @@ SimpleRenderer::get_camera_pixelaspect(ShaderGlobals* /*sg*/, bool derivs,
                                        ustringhash /*object*/, TypeDesc type,
                                        ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_pixelaspect;
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
@@ -830,7 +828,7 @@ SimpleRenderer::get_camera_clip_near(ShaderGlobals* /*sg*/, bool derivs,
                                      ustringhash /*object*/, TypeDesc type,
                                      ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_hither;
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
@@ -845,7 +843,7 @@ SimpleRenderer::get_camera_clip_far(ShaderGlobals* /*sg*/, bool derivs,
                                     ustringhash /*object*/, TypeDesc type,
                                     ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_yon;
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
@@ -877,7 +875,7 @@ SimpleRenderer::get_camera_shutter_open(ShaderGlobals* /*sg*/, bool derivs,
                                         ustringhash /*object*/, TypeDesc type,
                                         ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_shutter[0];
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
@@ -892,7 +890,7 @@ SimpleRenderer::get_camera_shutter_close(ShaderGlobals* /*sg*/, bool derivs,
                                          ustringhash /*object*/, TypeDesc type,
                                          ustringhash /*name*/, void* val)
 {
-    if (type == TypeDesc::TypeFloat) {
+    if (type == TypeFloat) {
         ((float*)val)[0] = m_shutter[1];
         if (derivs)
             memset((char*)val + type.size(), 0, 2 * type.size());
